/**
 * OpenGL 3.x with GLEW and GLUT
 *
 * author	Po-Ying Li bylee@nchc.org.tw
 * version	1.0
 *
 * Homepage: http://viml.nchc.org.tw
 *
 * Copyright Po-Ying Li
 */

#ifndef _MYSHADER
#define _MYSHADER

bool AttachProgram( GLuint uProgram, const char* cpShader, GLenum eShaderType )
{
	GLuint  uShader;
	GLint   iCompleted;

	uShader = glCreateShader( eShaderType ); 
	glShaderSource( uShader, 1, &cpShader, NULL ); 
	glCompileShader( uShader ); 
	glGetShaderiv( uShader, GL_COMPILE_STATUS, &iCompleted ); 

	if ( !iCompleted ) 
	{ 
		GLint  len; 
		char*  msg; 
		glGetShaderiv( uShader, GL_INFO_LOG_LENGTH, &len ); 
		msg = (char*) malloc( len ); 
		glGetShaderInfoLog( uShader, len, &len, msg ); 
		fprintf( stderr, "Vertex shader compilation failure:\n%s\n", msg ); 
		free( msg ); 
		return false;
	}else
	{
		glAttachShader( uProgram, uShader ); 
		return true;
	}
}
bool LinkProgram( GLuint uProgram)
{
	GLint   iCompleted;
	glLinkProgram( uProgram ); 
	glGetProgramiv( uProgram, GL_LINK_STATUS, &iCompleted ); 

	if ( !iCompleted ) 
	{
		GLint  len; 
		char*  msg; 

		glGetProgramiv( uProgram, GL_INFO_LOG_LENGTH, &len ); 
		msg = (char*) malloc( len ); 
		glGetProgramInfoLog( uProgram, len, &len, msg ); 
		fprintf( stderr, "Program link failure:\n%s\n", msg ); 
		free( msg ); 
		glDeleteProgram( uProgram ); 
		return false; 
	}

	glValidateProgram(uProgram);
	glGetProgramiv( uProgram, GL_VALIDATE_STATUS, &iCompleted ); 

	if ( !iCompleted ) 
	{
		GLint  len; 
		char*  msg; 

		glGetProgramiv( uProgram, GL_INFO_LOG_LENGTH, &len ); 
		msg = (char*) malloc( len ); 
		glGetProgramInfoLog( uProgram, len, &len, msg ); 
		fprintf( stderr, "Program link failure:\n%s\n", msg ); 
		free( msg ); 
		glDeleteProgram( uProgram ); 
		return false; 
	}

	return true;
}

#endif